@@ -6,7 +6,7 @@ This module provides evaluation methods that match lm-eval's native approaches:
 - Exact match evaluation for precise answer matching
 - F1 evaluation for token-level comparison
 - Perplexity evaluation for language modeling
-- Personalization evaluation for personality trait manifestation
+- Coding evaluation for code generation tasks
 """
 
 from .log_likelihoods_evaluator import LogLikelihoodsEvaluator
@@ -14,7 +14,7 @@ from .generation_evaluator import GenerationEvaluator
 from .exact_match_evaluator import ExactMatchEvaluator
 from .f1_evaluator import F1Evaluator
 from .perplexity_evaluator import PerplexityEvaluator
-from .personalization_evaluator import PersonalizationEvaluator
+from .docker_code_evaluator import DockerCodeEvaluator
 
 __all__ = [
     'LogLikelihoodsEvaluator',
@@ -22,5 +22,5 @@ __all__ = [
     'ExactMatchEvaluator',
     'F1Evaluator',
     'PerplexityEvaluator',
-    'PersonalizationEvaluator',
+    'DockerCodeEvaluator',
 ]
